Praxis Seizure: Québec Quebec City, Quebec March 12th 2000 10 players Pierre-Hugues https://groups.google.com/d/topic/rec.games.trading-cards.jyhad/A4KeFkLd7vs/discussion https://groups.google.com/d/topic/rec.games.trading-cards.jyhad/V_BtAYAXXSk/discussion Here's the results of the first canadian DCI-sanctionned-VTES-constructed-deck Tournament It was a hard fight for Pierre-Hugues, who has won his place for the final only in the 3rd round. With the efforts he made in dealing with others for votes, we can say that he surely deserves his title of Primogen Ventrue ! HIGHER POWER Deck Ventrue Crypt (12 cards, min=14, max=31, avg=5.5) ----------------------------------------- 2x Sir Walter Nash 7 DOM FOR PRE prince Ventrue:1 2x Ranjan Rishi, Camarilla Scholar 5 DOM PRE for Ventrue:2 1x Democritus 10 DOM PRE aus cel for justicar Ventrue:1 1x Timothy Crowley 7 FOR PRE ani dom prince Ventrue:1 1x Heather Florent, The Opportunist 6 FOR PRE dom Ventrue:1 1x Jazz Wentworth 5 PRE dom for Ventrue:1 1x Courtland Leighton 4 dom for pre Ventrue:1 1x Violette Prentiss 4 PRE dom Ventrue:1 1x Gideon Fontaine 3 PRE Ventrue:1 1x Roland Loussarian 3 for pre Ventrue:1 Library (87 cards) Master (18) 1x Archon Investigation 2x Blood Doll 2x Dominate 1x Elysium: The Arboretum 1x Fortitude 1x Giant's Blood 1x KRCG News Radio 1x Legendary Vampire 2x Minion Tap 1x Presence 2x Short-Term Investment 1x Sudden Reversal 1x Uptown Hunting Ground 1x Ventrue Headquarters Action (8) 2x Fifth Tradition: Hospitality 2x Govern the Unaligned 2x Legal Manipulations 2x Social Charm Equipment (1) 1x Palatial Estate Political Action (15) 1x Ancient Influence 1x Ancilla Empowerment 1x Banishment 2x Conservative Agitation 1x Disputed Territory 1x Domain Challenge 2x Kine Resources Contested 1x Parity Shift 1x Praxis Seizure: Berlin 1x Praxis Seizure: Cairo 1x Praxis Seizure: Geneva 1x Praxis Seizure: London 1x Ventrue Justicar Retainer (2) 1x Marijava Ghoul 1x Mr. Winthrop Action Modifier (21) 4x Bewitching Oration 3x Bonding 4x Bribes 1x Conditioning 1x Day Operation 1x Foreshadowing Destruction 1x Freak Drive 1x Kiss of Ra, The 1x Seduction 1x Threats 3x Voter Captivation Reaction (13) 2x Deflection 3x Elder Intervention 2x Obedience 3x Second Tradition: Domain 3x Wake with Evening's Freshness Combat (9) 2x Hidden Strength 1x Indomitability 5x Majesty 1x Skin of Rock